[Zope3-checkins] CVS: Zope3/src/zope/schema - interfaces.py:1.18

Fred L. Drake, Jr. fred@zope.com
Wed, 28 May 2003 10:34:28 -0400


Update of /cvs-repository/Zope3/src/zope/schema
In directory cvs.zope.org:/tmp/cvs-serv640

Modified Files:
	interfaces.py 
Log Message:
IAbstractVocabulary isn't exactly abstract; they can be directly
queriable, which can easily be all that's needed.


=== Zope3/src/zope/schema/interfaces.py 1.17 => 1.18 ===
--- Zope3/src/zope/schema/interfaces.py:1.17	Wed May 21 17:11:23 2003
+++ Zope3/src/zope/schema/interfaces.py	Wed May 28 10:34:28 2003
@@ -398,7 +398,7 @@
         )
 
 
-class IAbstractVocabulary(Interface):
+class IBaseVocabulary(Interface):
     """Representation of a vocabulary.
 
     At this most basic level, a vocabulary only need to support a test
@@ -468,7 +468,7 @@
         """Returns the vocabulary that this is a subset of."""
 
 
-class IVocabulary(IIterableVocabulary, IAbstractVocabulary):
+class IVocabulary(IIterableVocabulary, IBaseVocabulary):
     """Vocabulary which is iterable."""
 
 
@@ -486,11 +486,11 @@
 
     vocabulary = Attribute(
         "vocabulary",
-        ("IAbstractVocabulary to be used, or None.\n"
+        ("IBaseVocabulary to be used, or None.\n"
          "\n"
          "If None, the vocabularyName should be used by an\n"
          "IVocabularyRegistry should be used to locate an appropriate\n"
-         "IAbstractVocabulary object."))
+         "IBaseVocabulary object."))
 
 
 class IVocabularyField(IVocabularyFieldMixin, IField):
@@ -510,7 +510,7 @@
 
 
 class IVocabularyRegistry(Interface):
     """Registry that provides IAbstractVocabulary objects for specific fields.
     """
 
     def get(object, name):
@@ -510,7 +510,7 @@
 
 class IVocabularyRegistry(Interface):
-    """Registry that provides IAbstractVocabulary objects for specific fields.
+    """Registry that provides IBaseVocabulary objects for specific fields.
     """
 